@@ -15,4 +15,8 @@ REPORT_DIR = os.path.join(BASEDIR, "reports")
 # 测试用例模块所在的目录
 CASE_DIR = os.path.join(BASEDIR, "testcases")
 # DB目录
-DB_DIR = os.path.join(BASEDIR, "database")
\ No newline at end of file
+DB_DIR = os.path.join(BASEDIR, "database")
+# pytest.ini文件路径
+PYTEST_INI_DIR = os.path.join(BASEDIR, "pytest.ini")
+# aomaker html路径
+AOMAKER_HTML = os.path.join(REPORT_DIR, "aomaker.html")
